@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-io-error-message-area.c 6419 2008-08-16 16:53:47Z jessevdk $
+ * $Id$
  */
  
 /*
@@ -348,7 +348,8 @@ gedit_io_loading_error_message_area_new (const gchar  *uri,
 
 	g_return_val_if_fail (uri != NULL, NULL);
 	g_return_val_if_fail (error != NULL, NULL);
-	g_return_val_if_fail (error->domain == GEDIT_DOCUMENT_ERROR, NULL);
+	g_return_val_if_fail ((error->domain == GEDIT_DOCUMENT_ERROR) || 
+			      (error->domain == G_IO_ERROR), NULL);
 
 	full_formatted_uri = gedit_utils_uri_for_display (uri);
 
@@ -411,7 +412,8 @@ gedit_unrecoverable_reverting_error_message_area_new (const gchar  *uri,
 
 	g_return_val_if_fail (uri != NULL, NULL);
 	g_return_val_if_fail (error != NULL, NULL);
-	g_return_val_if_fail (error->domain == GEDIT_DOCUMENT_ERROR, NULL);
+	g_return_val_if_fail ((error->domain == GEDIT_DOCUMENT_ERROR) || 
+			      (error->domain == G_IO_ERROR), NULL);
 
 	full_formatted_uri = gedit_utils_uri_for_display (uri);
 
@@ -892,8 +894,10 @@ gedit_no_backup_saving_error_message_area_new (const gchar  *uri,
 
 	g_return_val_if_fail (uri != NULL, NULL);
 	g_return_val_if_fail (error != NULL, NULL);
-	g_return_val_if_fail (error->domain == GEDIT_DOCUMENT_ERROR, NULL);
-	g_return_val_if_fail (error->code == GEDIT_DOCUMENT_ERROR_CANT_CREATE_BACKUP, NULL);
+	g_return_val_if_fail (((error->domain == GEDIT_DOCUMENT_ERROR &&
+			        error->code == GEDIT_DOCUMENT_ERROR_CANT_CREATE_BACKUP) ||
+			       (error->domain == G_IO_ERROR &&
+			        error->code == G_IO_ERROR_CANT_CREATE_BACKUP)), NULL);
 
 	full_formatted_uri = gedit_utils_uri_for_display (uri);
 
@@ -988,7 +992,8 @@ gedit_unrecoverable_saving_error_message_area_new (const gchar  *uri,
 
 	g_return_val_if_fail (uri != NULL, NULL);
 	g_return_val_if_fail (error != NULL, NULL);
-	g_return_val_if_fail (error->domain == GEDIT_DOCUMENT_ERROR, NULL);
+	g_return_val_if_fail ((error->domain == GEDIT_DOCUMENT_ERROR) || 
+			      (error->domain == G_IO_ERROR), NULL);
 
 	full_formatted_uri = gedit_utils_uri_for_display (uri);
 
