@@ -56,13 +56,19 @@ gedit_file_browser_utils_pixbuf_from_icon (GIcon * icon,
 	GdkPixbuf * ret = NULL;
 	GtkIconTheme *theme;
 	GtkIconInfo *info;
-	
+	gint width;
+
 	if (!icon)
 		return NULL;
 
 	theme = gtk_icon_theme_get_default ();
-	info = gtk_icon_theme_lookup_by_gicon (theme, icon, size, 0);
+	gtk_icon_size_lookup (size, &width, NULL);
 	
+	info = gtk_icon_theme_lookup_by_gicon (theme,
+					       icon,
+					       width,
+					       GTK_ICON_LOOKUP_USE_BUILTIN);
+
 	if (!info)
 		return NULL;
 		
@@ -90,21 +96,10 @@ gedit_file_browser_utils_pixbuf_from_file (GFile * file,
 		return NULL;
 
 	icon = g_file_info_get_icon (info);
-	ret = gedit_file_browser_utils_pixbuf_from_icon (icon, size);
-	g_object_unref (info);
-	
-	return ret;
-}
+	if (icon != NULL)
+		ret = gedit_file_browser_utils_pixbuf_from_icon (icon, size);
 
-gchar *
-gedit_file_browser_utils_file_display (GFile * file)
-{
-	gchar *uri;
-	gchar *ret;
-	
-	uri = g_file_get_uri (file);
-	ret = gedit_utils_uri_for_display (uri);
-	g_free (uri);
+	g_object_unref (info);
 	
 	return ret;
 }
